@@ -3,7 +3,7 @@ use warnings;
 
 package JMAP::Tester;
 # ABSTRACT: a JMAP client made for testing JMAP servers
-$JMAP::Tester::VERSION = '0.016';
+$JMAP::Tester::VERSION = '0.017';
 use Moo;
 
 use Crypt::Misc qw(decode_b64u encode_b64u);
@@ -19,6 +19,7 @@ use JMAP::Tester::Result::Failure;
 use JMAP::Tester::Result::Logout;
 use JMAP::Tester::Result::Upload;
 use Module::Runtime ();
+use Params::Util qw(_HASH0 _ARRAY0);
 use URI;
 use URI::QueryParam;
 use Scalar::Util qw(weaken);
@@ -66,12 +67,12 @@ use namespace::clean;
 #pod L<JSON::Typist>, so you may want to strip their type data before using normal
 #pod Perl code on them.  You can do that with:
 #pod
-#pod   my $struct = $response->as_struct;   # gets the complete JSON data
+#pod   my $struct = $response->as_triples;  # gets the complete JSON data
 #pod   $jtest->strip_json_types( $struct ); # strips all the JSON::Typist types
 #pod
 #pod Or more simply:
 #pod
-#pod   my $struct = $response->as_stripped_struct;
+#pod   my $struct = $response->as_stripped_triples;
 #pod
 #pod There is also L<JMAP::Tester::Response/"as_stripped_pairs">.
 #pod
@@ -186,10 +187,13 @@ has default_arguments => (
 #pod     [ methodTwo => { ... } ],
 #pod   ]);
 #pod
-#pod This method takes an arrayref of method calls and sends them to the JMAP
-#pod server.  If the method calls have a third element (a I<client id>) then it's
-#pod left as-is.  If no client id is given, one is generated.  You can mix
-#pod explicit and autogenerated client ids.  They will never conflict.
+#pod This method accepts either an arrayref of method calls or a hashref with a
+#pod C<methodCalls> key.  It sends the calls to the JMAP server and returns a
+#pod result.
+#pod
+#pod For each method call, if there's a third element (a I<client id>) then it's
+#pod left as-is.  If no client id is given, one is generated.  You can mix explicit
+#pod and autogenerated client ids.  They will never conflict.
 #pod
 #pod The arguments to methods are JSON-encoded with a L<JSON::Typist>-aware encoder,
 #pod so JSON::Typist types can be used to ensure string or number types in the
@@ -205,7 +209,7 @@ has default_arguments => (
 #pod =cut
 
 sub request {
-  my ($self, $calls) = @_;
+  my ($self, $input_request) = @_;
 
   Carp::confess("can't perform request: no api_uri configured")
     unless $self->has_api_uri;
@@ -216,7 +220,11 @@ sub request {
 
   my %default_args = %{ $self->default_arguments };
 
-  for my $call (@$calls) {
+  my $request = _ARRAY0($input_request)
+              ? { methodCalls => $input_request }
+              : { %$input_request };
+
+  for my $call (@{ $request->{methodCalls} }) {
     my $copy = [ @$call ];
     if (defined $copy->[2]) {
       $seen{$call->[2]}++;
@@ -245,7 +253,12 @@ sub request {
     push @suffixed, $copy;
   }
 
-  my $json = $self->json_encode(\@suffixed);
+  $request->{methodCalls} = \@suffixed;
+
+  $request = $request->{methodCalls}
+    if $ENV{JMAP_TESTER_NO_WRAPPER} && _ARRAY0($input_request);
+
+  my $json = $self->json_encode($request);
 
   my $post = HTTP::Request->new(
     POST => $self->api_uri,
@@ -281,21 +294,38 @@ sub request {
     });
   }
 
-  # TODO check that it's really application/json!
+  return $self->_jresponse_from_hresponse($http_res);
+}
 
-  my $data = $self->apply_json_types(
-    $self->json_decode( $http_res->decoded_content )
-  );
+sub _jresponse_from_hresponse {
+  my ($self, $http_res) = @_;
+
+  # TODO check that it's really application/json!
+  my $json = $http_res->decoded_content;
+
+  my $data = $self->apply_json_types( $self->json_decode( $json ) );
+
+  my ($items, $props);
+  if (_HASH0($data)) {
+    $props = $data;
+    $items = $props->{methodResponses};
+  } elsif (_ARRAY0($data)) {
+    $props = {};
+    $items = $data;
+  } else {
+    abort("illegal response to JMAP request: $data");
+  }
 
   $self->_logger->log_jmap_response({
-    jmap_array    => $data,
-    json          => $http_res->decoded_content,
+    jmap_array    => $items,
+    json          => $json,
     http_response => $http_res,
   });
 
   return JMAP::Tester::Response->new({
-    items => $data,
-    http_response   => $http_res,
+    items => $items,
+    http_response       => $http_res,
+    wrapper_properties  => $props,
   });
 }
 
@@ -742,7 +772,7 @@ JMAP::Tester - a JMAP client made for testing JMAP servers
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 OVERVIEW
 
@@ -784,12 +814,12 @@ By default, all the structures returned have been passed through
 L<JSON::Typist>, so you may want to strip their type data before using normal
 Perl code on them.  You can do that with:
 
-  my $struct = $response->as_struct;   # gets the complete JSON data
+  my $struct = $response->as_triples;  # gets the complete JSON data
   $jtest->strip_json_types( $struct ); # strips all the JSON::Typist types
 
 Or more simply:
 
-  my $struct = $response->as_stripped_struct;
+  my $struct = $response->as_stripped_triples;
 
 There is also L<JMAP::Tester::Response/"as_stripped_pairs">.
 
@@ -826,10 +856,13 @@ The request will effectively be:
     [ methodTwo => { ... } ],
   ]);
 
-This method takes an arrayref of method calls and sends them to the JMAP
-server.  If the method calls have a third element (a I<client id>) then it's
-left as-is.  If no client id is given, one is generated.  You can mix
-explicit and autogenerated client ids.  They will never conflict.
+This method accepts either an arrayref of method calls or a hashref with a
+C<methodCalls> key.  It sends the calls to the JMAP server and returns a
+result.
+
+For each method call, if there's a third element (a I<client id>) then it's
+left as-is.  If no client id is given, one is generated.  You can mix explicit
+and autogenerated client ids.  They will never conflict.
 
 The arguments to methods are JSON-encoded with a L<JSON::Typist>-aware encoder,
 so JSON::Typist types can be used to ensure string or number types in the
